@@ -1,5 +1,5 @@
 # ===========================================================================
-# Crypt::GCrypt
+# Crypt::GCrypt - version 1.1 - 10 Oct 2005
 # 
 # Perl interface to the GNU Cryptographic library
 # 
@@ -15,7 +15,7 @@ package Crypt::GCrypt;
 use strict;
 use warnings;
 
-our $VERSION = '1.1.2';
+our $VERSION = '1.1';
 
 require XSLoader;
 XSLoader::load('Crypt::GCrypt', $VERSION);
@@ -31,7 +31,7 @@ Crypt::GCrypt - Perl interface to the GNU Cryptographic library
 
   use Crypt::GCrypt;
   
-  $cipher = Crypt::GCrypt->new(
+  $cipher = GCrypt::Cipher->new(
     type => 'cipher',
     algorithm => 'aes', 
     mode => 'cbc'
@@ -39,6 +39,7 @@ Crypt::GCrypt - Perl interface to the GNU Cryptographic library
   $cipher->start('encrypting');
   
   $cipher->setkey('my secret key');
+  
   $cipher->setiv('my init vector');
   
   $ciphertext = $cipher->encrypt('plaintext');
@@ -49,8 +50,8 @@ Crypt::GCrypt - Perl interface to the GNU Cryptographic library
 =head1 ABSTRACT
 
 Crypt::GCrypt provides an object interface to the C libgcrypt library. It
-currently supports symmetric encryption/decryption, while asymmetric 
-cryptography is being worked on.
+currently supports symmetric encryption, while asymmetric encryption is 
+being worked on.
 
 =head1 SYMMETRIC CRYPTOGRAPHY
 
@@ -207,35 +208,35 @@ the cipher for encryption or decryption, resetting the internal state.
 
 =head2 setkey()
 
-   $cipher->setkey('my secret key');
+   $cipher->setkey('my secret key')
 
-Encryption and decryption operations will use this key until a different
-one is set. If your key is shorter than the cipher's keylen (see the
+Encryption and decryption operations will use I<KEY> until a different
+one is set. If I<KEY> is shorter than the cipher's keylen (see the
 C<keylen> method) it will be zero-padded, if it is longer it will be
 truncated.
 
 =head2 setiv()
 
-   $cipher->setiv('my iv');
+   $cipher->setiv('my iv')
 
-Set the initialisation vector for the next encrypt/decrypt operation.
+Set the initialisation vector to I<IV> for the next encrypt/decrypt operation.
 If I<IV> is missing a "standard" IV of all zero is used. The same IV is set in
 newly created cipher objects.
 
 =head2 encrypt()
 
-   $cipher->encrypt($plaintext);
+   $cipher->encrypt($plaintext)
 
-This method encrypts I<$plaintext> with I<$cipher>, returning the
+This method encrypts I<PLAINTEXT> with $cipher, returning the
 corresponding ciphertext. Null byte padding is automatically appended
 if I<PLAINTEXT>'s length is not evenly divisible by $cipher's block
 size.
 
 =head2 decrypt()
 
-   $cipher->decrypt($ciphertext);
+   $cipher->decrypt($ciphertext)
 
-The counterpart to encrypt, decrypt takes a I<$ciphertext> and produces the
+The counterpart to encrypt, decrypt takes a I<CIPHERTEXT> and produces the
 original plaintext (given that the right key was used, of course).
 
 =head2 finish()
